@@ -15,28 +15,27 @@ Mdif class and utilities
 
 """
 import numpy as np
-import typing
-import sys
-from itertools import product
+from typing import Union, TextIO
 from ..util import get_fid
 from ..frequency import Frequency
 from ..network import Network, z2s, y2s
 from ..networkSet import NetworkSet
 from ..mathFunctions import magdeg_2_reim
+from itertools import product
 
 class Mdif():
     """
     Class to read Generalized MDIF N-port files.
-
-    Used to read the Generalized MDIF (GMDIF) file format [#]_ (.mdf extension).
-    These files are used store Network parameters which vary with frequency
-    and with one or more named parameters.
+    
+    Used to read the Generalized MDIF (GMDIF) file format [#]_ (.mdf extension). 
+    These files are used store Network parameters which vary with frequency 
+    and with one or more named parameters. 
 
     Parameters
     ----------
     file : str or file-object
         mdif file to load
-
+                                                        
     References
     ----------
     .. [#] https://awrcorp.com/download/faq/english/docs/Users_Guide/data_file_formats.html#generalized_mdif
@@ -51,13 +50,13 @@ class Mdif():
 
     >>> file = open('network.mdf')
     >>> m = rf.Mdif(file)
-
+    
     List of named parameters defined in the MDIF file
-
+    
     >>> m.params
-
+    
     Convert the MDIF to a NetworkSet
-
+    
     >>> m.to_networkset()
 
     Using the data as a `NetworkSet` allows you to select a set of Networks
@@ -65,15 +64,15 @@ class Mdif():
     See `skrf.networkset.NetworkSet`.
 
     """
-
-    def __init__(self, file: typing.Union[str, typing.TextIO]):
+    
+    def __init__(self, file: Union[str, TextIO]):
         """
         Constructor
-
+        
         Parameters
         ----------
         file : str or file-object
-            mdif file to load
+            mdif file to load        
         """
         with get_fid(file) as fid:
             self.filename = fid.name
@@ -111,7 +110,7 @@ class Mdif():
     def networks(self) -> list:
         """
         List of Networks.
-
+        
         Returns
         -------
         list : list of :class:`~skrf.network.Network`
@@ -171,6 +170,7 @@ class Mdif():
         formt = 'ri'
         z0 = 50
         nb_lines_per_freq = 1
+        ntwk_name = ''
 
         # Extract and group parameter informations and values
         for line in block_data:
@@ -190,6 +190,10 @@ class Mdif():
                 if formt not in ['ma', 'db', 'ri']:
                     raise NotImplementedError(f'ERROR: illegal format value {formt}')
 
+            elif line.startswith('!'):
+                if line[1:].startswith(' network name:'):
+                    ntwk_name = line.split(':')[-1].strip()
+                    
 
             # Parameter kinds (s11, z21, ...) are described as
             #
@@ -238,8 +242,11 @@ class Mdif():
 
         # Nport as in AWR MDIF file-format description
         elif (parameter == 's') and all(k in kinds for k in ['n11x', 'n11y']):
-            rank = round(np.sqrt(sum('n' in s for s in kinds)/2))
+            rank = round(np.sqrt(sum('n' in s for s in kinds)/2))                 
             s = values[:,:rank**2].reshape(len(f), rank, rank)
+            # if rank is 2 and S21 before S12, swap S21 and S12 
+            if rank == 2 and (kinds.index('n21x') < kinds.index('n12x')):
+                s[:, 1, 0], s[:, 0, 1] =  s[:, 0, 1].copy(), s[:, 1, 0].copy()
 
         # no S-parameter are found. Maybe Z-param instead?
         elif ('z[1,1]') in kinds:
@@ -248,7 +255,7 @@ class Mdif():
             z = np.zeros((len(f), rank, rank), dtype=complex)
             for m in range(rank):
                 for n in range(rank):
-                    z[:,m,n] = values[:, kinds.index(f'z[{m+1},{n+1}]') - 1]
+                    z[:,m,n] = values[:, kinds.index(f'z[{m+1},{n+1}]') - 1]            
             s = z2s(z, z0=z0)
 
         # no S nor Z-parameter are found. Maybe Y-param instead?
@@ -258,15 +265,15 @@ class Mdif():
             y = np.zeros((len(f), rank, rank), dtype=complex)
             for m in range(rank):
                 for n in range(rank):
-                    y[:,m,n] = values[:, kinds.index(f'y[{m+1},{n+1}]') - 1]
+                    y[:,m,n] = values[:, kinds.index(f'y[{m+1},{n+1}]') - 1]            
             s = y2s(z, z0=z0)
-
+            
         else:
             raise NotImplementedError('Unrecognized case, probably not implemented')
 
         # building the Network
         freq = Frequency.from_f(f, unit=frequency_unit)
-        ntwk = Network(frequency=freq, s=s, z0=z0)
+        ntwk = Network(frequency=freq, s=s, z0=z0, name=ntwk_name)
 
         return ntwk
 
@@ -303,12 +310,14 @@ class Mdif():
                 in_a_block = True
                 # current parameter
                 param_name, param_value = [s.strip() for s in line[3:].split('=')]
+                # remove the datatype "(blah)" in "varname(blah)" if any
+                param_name = param_name.split('(')[0]
                 # try to convert the value as a number
                 self._params.append(param_name) if param_name not in self.params else self.params
                 try:
                     params[param_name] = float(param_value)
                 except ValueError:
-                    params[param_name] = param_value
+                    params[param_name] = param_value.replace('"', '')
 
             # parse numerical data:
             #
@@ -337,26 +346,122 @@ class Mdif():
 
     def to_networkset(self) -> NetworkSet:
         """
-        Return the MDIF data as a NetworkSet
+        Return the MDIF data as a NetworkSet.
 
         Returns
         -------
-        NetworkSet
+        ns : :class:`~skrf.networkSet.NetworkSet`
+        
+        See Also
+        --------
+        from_networkset : Write a MDIF file from a NetworkSet.
 
         """
         ns = NetworkSet(self.networks)
         ns.comments = self.comments
         return ns
 
+    @staticmethod
+    def write(ns : NetworkSet,
+              filename : str,
+              values: Union[dict, None] = None,
+              data_types: Union[dict, None] = None,
+              comments = []):
+        """
+        Write a MDIF file from a NetworkSet.
+
+        Parameters
+        ----------
+        ns : :class:`~skrf.networkSet.NetworkSet`
+            NetworkSet to get the data from.
+        filename : string
+            Output MDIF file name.
+        values : dictionary or None. Default is None.
+            The keys of the dictionnary are MDIF variables and its values are
+            a list of the parameter values.
+            If None, then the values will be set to the NetworkSet names
+            and the datatypes will be set to "string".
+        data_types: dictionary or None. Default is None.
+            The keys are MDIF variables and the value are datatypes
+            specified by the following strings: "int", "double", and "string"
+        comments: list of strings
+            Comments to add to output_file.
+            Each list items is a separate comment line
+            
+        See Also
+        --------
+        io.mdif.Mdif : MDIF file class
+        to_networkset : Return the MDIF data as a NetworkSet
+        
+        """
+
+        if values is None:
+            if ns.has_params():
+                values = ns.params_values
+            else:
+                # using Network names as values
+                v = list()
+                for ntwk in ns:
+                    v.append(ntwk.name)
+
+                values = {"name": v}
+
+        if data_types is None:
+            if ns.has_params():
+                data_types = ns.params_types
+            else:
+                # using Network names (->string)
+                data_types = {"name": "string"}
+
+        # VAR datatypes
+        dict_types = dict({"int": "0", "double": "1", "string": "2"})
+
+        # open output_file
+        with open(filename, "w") as mdif:
+
+            # write comments
+            for c in comments:
+                mdif.write(f"! {c}\n")
+
+            nports = ns[0].nports
+
+            optionstring = Mdif.__create_optionstring(nports)
+
+            for filenumber, ntwk in enumerate(ns):
+
+                mdif.write("!" + "-" * 79 + "\n")
+
+                for p in values:
+                    # assign double as the datatype if none is specified
+                    if p not in data_types:
+                        data_types[p] = "double"
+
+                    if data_types[p] == "string":
+                        var_def_str = 'VAR {}({}) = "{}"'.format(
+                            p, dict_types[data_types[p]], values[p][filenumber]
+                        )
+                    else:
+                        var_def_str = "VAR {}({}) = {}".format(
+                            p, dict_types[data_types[p]], values[p][filenumber]
+                        )
+                    mdif.write(var_def_str + "\n")
+
+                mdif.write("\nBEGIN ACDATA\n")
+                mdif.write(optionstring + "\n")
+                mdif.write("! network name: " + ntwk.name + "\n")
+                data = ntwk.write_touchstone(return_string=True)
+                mdif.write(data)
+                mdif.write("END\n\n")
+
     def __eq__(self, other) -> bool:
         """
         Test if two Mdif objects are equals.
-
+        
         Test the equality between the NetworkSet under the hood.
 
         Parameters
         ----------
-        other : `skrf.io.mdif.Mdif` object
+        other : :class:`~skrf.io.mdif.Mdif` object
             Mdif object to compare with.
 
         Returns
@@ -365,94 +470,11 @@ class Mdif():
 
         """
         return self.to_networkset() == other.to_networkset()
+    
+    @staticmethod
+    def __create_optionstring(nports):
+        """create the options string based on the number of ports. Used in the Touchstone and MDIF formats"""
 
-    def to_mdif(self, networkset: NetworkSet, output_file: str,
-                values=None, datatypes=None, comments=[]):
-        """
-        Convert a NetworkSet to an Generated MDIF file.
-
-        if values==None then use networkset names.
-
-        `comments` is a list (each element is separate comment line)
-
-        Parameters
-        ----------
-        networkset : NetworkSet
-            NetworkSet object to convert into a .mdif file.
-        output_file : str
-            MDIF file path
-        values : TYPE, optional
-            DESCRIPTION. The default is None.
-        datatypes : TYPE, optional
-            DESCRIPTION. The default is None.
-        comments : list, optional
-            Comments to store in the file. The default is [].
-
-        """
-
-        if values == None:
-            v = list()
-            for ns in networkset:
-                v.append(ns.name)
-
-            values = {"name": v}
-            datatypes = {"name": "string"}
-
-        # VAR datatypes
-        dict_types = dict({"int": "0", "double": "1", "string": "2"})
-
-        try:
-            mdif = open(output_file, "w")
-        except:
-            print("Error:", sys.exc_info()[0])
-
-        # write comments
-        for c in comments:
-            mdif.write(f"! {c}\n")
-
-        nports = networkset[0].nports
-
-        optionstring = self.__create_optionstring(nports)
-
-        for filenumber, ntwk in enumerate(networkset):
-            # print("[INFO]: Processing {} Port file: {}".format(nports, ntwk.name))
-
-            mdif.write("!" + "-" * 79 + "\n! network name: " + ntwk.name + "\n\n")
-
-            for p in values:
-                # assign double as the datatype if none is specified
-                if p not in datatypes:
-                    datatypes[p] = "double"
-
-                if datatypes[p] == "string":
-                    var_def_str = 'VAR {}({}) = "{}"'.format(p, dict_types[datatypes[p]], values[p][filenumber])
-                else:
-                    var_def_str = "VAR {}({}) = {}".format(p, dict_types[datatypes[p]], values[p][filenumber])
-
-                mdif.write(var_def_str + "\n")
-
-            mdif.write("\nBEGIN ACDATA\n")
-            mdif.write(optionstring + "\n")
-            data = ntwk.write_touchstone(return_string=True)
-            mdif.write(data)
-            mdif.write("END\n\n")
-
-        mdif.close()
-
-    def __create_optionstring(self, nports):
-        """
-        Generate the string
-
-        Parameters
-        ----------
-        nports : int
-            Number of ports
-
-        Returns
-        -------
-        optionstring : str
-
-        """
         if nports > 9:
             corestring = "n{}_{}x n{}_{}y "
         else:
@@ -480,8 +502,8 @@ class Mdif():
                 if nports >= 4:
                     if np.remainder(i[1], 4) == 0:
                         optionstring += "\n"
-                    # NOTE: not sure if this is needed. Doesn't seem to be
-                    # required by Microwave Office
+                    # NOTE: not sure if this is needed. Doesn't seem to be required by Microwave Office
                     if i[1] == nports:
                         optionstring += "\n"
-        return optionstring
+
+        return optionstring    
\ No newline at end of file
