@@ -1,7 +1,7 @@
 from skrf.mathFunctions import LOG_OF_NEG
 import skrf as rf
 import unittest
-import numpy as np
+import numpy as npy
 from numpy import e, log, pi, isnan, inf
 from numpy.testing import assert_equal, run_module_suite, assert_almost_equal
 
@@ -12,7 +12,7 @@ class TestUnitConversions(unittest.TestCase):
     """
 
     def setUp(self):
-        pass        
+        pass
 
     def test_complex_2_magnitude(self):
         """
@@ -20,7 +20,7 @@ class TestUnitConversions(unittest.TestCase):
             5 = 3 + 4j
         """
         assert_almost_equal(rf.complex_2_magnitude(3+4j), 5.0)
-        
+
 
     def test_complex_2_db10(self):
         """
@@ -41,7 +41,7 @@ class TestUnitConversions(unittest.TestCase):
     def test_complex_2_quadrature(self):
         """
         Test complex to quadrature conversion with:
-            2, pi  = abs(2j), angle(2j) * abs(2j) 
+            2, pi  = abs(2j), angle(2j) * abs(2j)
         """
         assert_almost_equal(rf.complex_2_quadrature(0+2j), (2, pi))
 
@@ -74,7 +74,7 @@ class TestUnitConversions(unittest.TestCase):
 
         assert_equal(rf.mag_2_db, rf.magnitude_2_db) # Just an alias
 
-        
+
     def test_mag_2_db10(self):
         """
         Test magnitude to db10 conversion
@@ -119,7 +119,7 @@ class TestUnitConversions(unittest.TestCase):
 
     def test_db_2_np(self):
         """
-        Test dB to Np conversion with: 
+        Test dB to Np conversion with:
             1 [dB] = ln(10)/20 [Np]
         """
         assert_almost_equal(rf.db_2_np(1), log(10)/20)
@@ -135,7 +135,7 @@ class TestUnitConversions(unittest.TestCase):
         """
         assert_almost_equal(rf.feet_2_meter(0.01), 0.003048)
         assert_almost_equal(rf.feet_2_meter(1), 0.3048)
-        
+
 
     def test_meter_2_feet(self):
         """
@@ -158,15 +158,39 @@ class TestUnitConversions(unittest.TestCase):
         Test inf_to_num function
         """
         # scalar
-        assert_equal(rf.inf_to_num(np.inf), rf.INF)
-        assert_equal(rf.inf_to_num(-np.inf), -rf.INF)
-        
+        assert_equal(rf.inf_to_num(npy.inf), rf.INF)
+        assert_equal(rf.inf_to_num(-npy.inf), -rf.INF)
+
         # array
-        x = np.array([0, np.inf, 0, -np.inf])
-        y = np.array([0, rf.INF, 0, -rf.INF])
+        x = npy.array([0, npy.inf, 0, -npy.inf])
+        y = npy.array([0, rf.INF, 0, -rf.INF])
         assert_equal(rf.inf_to_num(x), y)
 
+    def test_rsolve(self):
+        A = npy.random.random((3, 2, 2)) + 1j*npy.random.random((3, 2, 2))
+        B = npy.random.random((3, 2, 2)) + 1j*npy.random.random((3, 2, 2))
+        # Make sure they are not singular
+        A = rf.nudge_eig(A)
+        B = rf.nudge_eig(B)
+
+        x = rf.rsolve(A, B)
+        npy.testing.assert_allclose(x @ A, B)
+
+    def test_nudge_eig(self):
+        A = npy.zeros((3, 2, 2))
+        cond_A = npy.linalg.cond(A)
+        A2 = rf.nudge_eig(A, cond=1e-9, min_eig=1e-12)
+
+        self.assertFalse(A is A2)
+        self.assertTrue(npy.all(npy.linalg.cond(A2) < cond_A))
+        npy.testing.assert_allclose(A2, A, atol=1e-9)
+
+    def test_nudge_eig2(self):
+        A = npy.diag([1, 1, 1, 1]).reshape(1, 4, 4)
+        A2 = rf.nudge_eig(A, cond=1e-9, min_eig=1e-12)
+        self.assertTrue(A is A2)
+
 if __name__ == "__main__":
     # Launch all tests
     run_module_suite()
-    
+
