@@ -132,7 +132,7 @@ class NetworkTestCase(unittest.TestCase):
             t1, y1[:,i,j] = oneport.step_response(n=1000)
 
         t2, y2 = dut_dc.step_response(n=1000)
-        
+
         npy.testing.assert_almost_equal(t1, t2)
         npy.testing.assert_almost_equal(y1, y2)
 
@@ -190,7 +190,7 @@ class NetworkTestCase(unittest.TestCase):
             sio = io.StringIO(data)
             sio.name = os.path.basename(filename) # hack a bug to touchstone reader
             rf.Network(sio)
-            
+
         filename = os.path.join(self.test_dir, 'hfss_oneport.s1p')
         with open(filename) as fid:
             data = fid.read()
@@ -198,6 +198,61 @@ class NetworkTestCase(unittest.TestCase):
             sio.name = os.path.basename(filename) # hack a bug to touchstone reader
             rf.Network(sio)
 
+    def test_constructor_from_parameters(self):
+        """Test creating Network from all supported parameters
+        with default z0 and specified z0.
+        """
+        random_z0 = npy.random.uniform(0.1, 1, (1, 2)) + \
+                1j*npy.random.uniform(0.1, 1, (1, 2))
+        for z0 in [None, random_z0]:
+            for param in rf.Network.PRIMARY_PROPERTIES:
+                params = npy.random.uniform(0.1, 1, (1, 2, 2)) + \
+                        1j*npy.random.uniform(0.1, 1, (1, 2, 2))
+                kwargs = {param:params}
+                if z0 is not None:
+                    kwargs['z0'] = z0
+                net = rf.Network(**kwargs)
+                if z0 is not None:
+                    npy.testing.assert_allclose(net.z0, z0)
+                npy.testing.assert_allclose(getattr(net, param), params)
+
+    def test_constructor_from_parameters2(self):
+        """Test creating Network from all supported parameters
+        with default z0 and specified z0.
+        Multiple frequency points and z0 broadcasted
+        """
+        random_z0 = npy.random.uniform(0.1, 1, 2) + \
+                1j*npy.random.uniform(0.1, 1, 2)
+        for z0 in [None, random_z0]:
+            for param in rf.Network.PRIMARY_PROPERTIES:
+                params = npy.random.uniform(0.1, 1, (5, 2, 2)) + \
+                        1j*npy.random.uniform(0.1, 1, (5, 2, 2))
+                kwargs = {param:params}
+                if z0 is not None:
+                    kwargs['z0'] = z0
+                net = rf.Network(**kwargs)
+                if z0 is not None:
+                    # Network z0 is broadcasted
+                    npy.testing.assert_allclose(net.z0[0,:], z0)
+                npy.testing.assert_allclose(getattr(net, param), params)
+
+    def test_constructor_invalid_networks(self):
+        with pytest.raises(Exception) as e_info:
+            # z0 size doesn't match
+            rf.Network(s=npy.zeros((2,2,2)), z0=[1,2,3])
+        with pytest.raises(Exception) as e_info:
+            # z0 size doesn't match, Z-parameters
+            rf.Network(z=npy.zeros((2,2,2)), z0=[1,2,3])
+        with pytest.raises(Exception) as e_info:
+            # Invalid s shape, non-square matrix
+            rf.Network(s=npy.zeros((2,2,1)))
+        with pytest.raises(Exception) as e_info:
+            # invalid s shape, too many dimensions
+            rf.network(s=npy.zeros((1,2,2,2)))
+        with pytest.raises(Exception) as e_info:
+            # Multiple input parameters
+            rf.network(s=1, z=1)
+
     def test_zipped_touchstone(self):
         zippath = os.path.join(self.test_dir, 'ntwks.zip')
         fname = 'ntwk1.s2p'
@@ -209,6 +264,68 @@ class NetworkTestCase(unittest.TestCase):
         self.assertEqual(self.ntwk1, ntwk1Saved)
         os.remove(os.path.join(self.test_dir, 'ntwk1Saved.s2p'))
 
+    def test_write_touchstone(self):
+        ports = 2
+        s_random = npy.random.uniform(-1, 1, (self.freq.npoints, ports, ports)) +\
+                1j * npy.random.uniform(-1, 1, (self.freq.npoints, ports, ports))
+        random_z0 = npy.random.uniform(1, 100, (self.freq.npoints, ports)) +\
+                    1j * npy.random.uniform(-100, 100, (self.freq.npoints, ports))
+        ntwk = rf.Network(s=s_random, frequency=self.freq, z0=random_z0, name='test_ntwk', s_def='traveling')
+
+        # Writing a network with non-constant z0 should raise
+        with pytest.raises(ValueError) as e_info:
+            snp = ntwk.write_touchstone(return_string=True)
+
+        ntwk.s_def = 'power'
+        # Should raise warning when write_z0 and s_def != 'traveling'.
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            snp = ntwk.write_touchstone(return_string=True, write_z0=True)
+            self.assertTrue(len(w) == 1)
+
+        ntwk.s_def = 'traveling'
+        # Ok if write_z0 specified
+        snp = ntwk.write_touchstone(return_string=True, write_z0=True)
+
+        # Test reading it back
+        strio = io.StringIO(snp)
+        # Required for reading touchstone file
+        strio.name = 'StringIO.s{}p'.format(ports)
+        ntwk2 = rf.Network(strio)
+
+        npy.testing.assert_allclose(ntwk2.s, s_random)
+        npy.testing.assert_allclose(ntwk2.z0, random_z0)
+
+        # Renormalize output to 50 ohms
+        snp = ntwk.write_touchstone(return_string=True, r_ref=50)
+
+        # Network should not have been modified
+        self.assertTrue(npy.all(ntwk.s == s_random))
+        self.assertTrue(npy.all(ntwk.z0 == random_z0))
+
+        # Read back the written touchstone
+        strio = io.StringIO(snp)
+        strio.name = 'StringIO.s{}p'.format(ports)
+        ntwk2 = rf.Network(strio)
+
+        # Renormalize original network to match the written one
+        ntwk.renormalize(50)
+
+        npy.testing.assert_allclose(ntwk.s, ntwk2.s)
+        npy.testing.assert_allclose(ntwk.z0, ntwk2.z0)
+
+        ntwk.z0[0, 0] = 1
+        # Writing network with non-constant real z0 should fail without r_ref
+        with pytest.raises(ValueError) as e_info:
+            snp = ntwk.write_touchstone(return_string=True)
+        ntwk.z0[0, 0] = 50
+
+        ntwk.renormalize(50 + 1j)
+
+        # Writing complex characteristic impedance should fail
+        with pytest.raises(ValueError) as e_info:
+            snp = ntwk.write_touchstone(return_string=True)
+
     def test_pickling(self):
         original_ntwk = self.ntwk1
         with tempfile.NamedTemporaryFile(dir=self.test_dir, suffix='ntwk') as fid:
@@ -251,7 +368,7 @@ class NetworkTestCase(unittest.TestCase):
             nport = rf.Network()
             nport.frequency = freq
             nport.s = npy.zeros((10, nport_portnum, nport_portnum))
-            nport.z0 = npy.arange(nport_portnum)
+            nport.z0 = npy.arange(start=1, stop=nport_portnum + 1)
 
             # Connect the line to each port and check for port impedance
             for port in range(nport_portnum):
@@ -274,6 +391,119 @@ class NetworkTestCase(unittest.TestCase):
         with self.assertRaises(ValueError):
             ntwk1**ntwk2
 
+    def test_connect_complex_ports(self):
+        """ Test that connecting two networks gives the same resulting network
+        (same Z-parameters) with all s_def when using complex port impedances.
+        """
+
+        # Generate random Z-parameters for two networks
+        z1 = npy.random.uniform(1, 100, size=(1, 2, 2)) +\
+                1j*npy.random.uniform(-100, 100, size=(1, 2, 2))
+        z2 = npy.random.uniform(1, 100, size=(1, 2, 2)) +\
+                1j*npy.random.uniform(-100, 100, size=(1, 2, 2))
+
+        # Port impedances
+        z0_1 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+        z0_2 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+        z0_3 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+
+        # Cascade Z-parameters calculated with ABCD parameters
+        net3_z = rf.a2z(rf.z2a(z1) @ rf.z2a(z2))
+
+        for s_def in rf.S_DEFINITIONS:
+            net3_ref = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_3, s_def=s_def)
+            net3_ref.z = net3_z
+
+            net1 = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_1, s_def=s_def)
+            net2 = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_2, s_def=s_def)
+            net1.z = z1
+            net2.z = z2
+
+            # Cascade calculated with S-parameters
+            net12 = net1 ** net2
+            net12.renormalize(z0_3)
+            self.assertTrue(net12.s_def == s_def)
+            self.assertTrue(net3_ref.s_def == s_def)
+            npy.testing.assert_almost_equal(net3_ref.z0, net12.z0)
+            npy.testing.assert_almost_equal(net12.s, net3_ref.s)
+            npy.testing.assert_almost_equal(net3_z, net3_ref.z)
+
+    def test_connect_different_s_def(self):
+        """ Test that connecting two networks gives the same resulting
+        network (same Z-parameters) with all s_def when using complex port
+        impedances.
+        """
+
+        # Generate random Z-parameters for two networks
+        z1 = npy.random.uniform(1, 100, size=(1, 2, 2)) +\
+                1j*npy.random.uniform(-100, 100, size=(1, 2, 2))
+        z2 = npy.random.uniform(1, 100, size=(1, 2, 2)) +\
+                1j*npy.random.uniform(-100, 100, size=(1, 2, 2))
+
+        # Port impedances
+        z0_1 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+        z0_2 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+        z0_3 = npy.random.uniform(1, 100, size=2) +\
+                1j*npy.random.uniform(-100, 100, size=2)
+
+        # Cascade Z-parameters calculated with ABCD parameters
+        net3_z = rf.a2z(rf.z2a(z1) @ rf.z2a(z2))
+
+        for s_def1 in rf.S_DEFINITIONS:
+            net3_ref = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_3, s_def=s_def1)
+            net3_ref.z = net3_z
+            net1 = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_1, s_def=s_def1)
+            net1.z = z1
+
+            for s_def2 in rf.S_DEFINITIONS:
+                net2 = rf.Network(s=[[0,0],[0,0]], f=1, z0=z0_2, s_def=s_def2)
+                net2.z = z2
+
+                # Cascade calculated with S-parameters
+                with warnings.catch_warnings(record=True) as w:
+                    # Trigger all warnings
+                    warnings.simplefilter("always")
+                    net12 = net1 ** net2
+                    # Check that method warns about connecting networks with
+                    # different s_def.
+                    if net1.s_def != net2.s_def:
+                        self.assertTrue(len(w) == 1)
+                    else:
+                        self.assertTrue(len(w) == 0)
+                net12.renormalize(z0_3)
+                self.assertTrue(net12.s_def == s_def1)
+                self.assertTrue(net3_ref.s_def == s_def1)
+                npy.testing.assert_almost_equal(net3_ref.z0, net12.z0)
+                npy.testing.assert_almost_equal(net12.s, net3_ref.s)
+                npy.testing.assert_almost_equal(net3_z, net3_ref.z)
+
+    def test_interconnect_complex_ports(self):
+        """ Test that connecting two complex ports in a network
+        gives the same S-parameters with all s_def when the rest of
+        the ports are real
+        """
+        for p in range(3, 5):
+            z = npy.random.uniform(1, 100, size=(1, p, p)) +\
+                    1j*npy.random.uniform(-100, 100, size=(1, p, p))
+            z0 = npy.random.uniform(1, 100, size=(1, p)) + 1j*0
+            z0[:, -2:] += 1j*npy.random.uniform(-100, 100, size=(1, 2))
+            nets = []
+            for s_def in rf.S_DEFINITIONS:
+                net = rf.Network(s=npy.zeros((p,p)), f=1, z0=z0, s_def=s_def)
+                net.z = z
+                # Connect the last two complex ports together
+                rf.innerconnect(net, p - 2, 2)
+                nets.append(net)
+            for net in nets[1:]:
+                npy.testing.assert_almost_equal(net.s, net[0].s)
+                self.assertTrue((net.z0 == net[0].z0).all())
+                self.assertTrue(net.s_def != net[0].s_def)
+
     def test_delay(self):
         ntwk1_delayed = self.ntwk1.delay(1,'ns',port=0)
         self.assertTrue(
@@ -365,12 +595,22 @@ class NetworkTestCase(unittest.TestCase):
         self.ntwk1.plot_s_smith()
 
     def test_zy_singularities(self):
-        open = rf.N(f=[1], s=[1], z0=[50])
-        short = rf.N(f=[1], s=[-1], z0=[50])
-        react = rf.N(f=[1],s=[[0,1],[1,0]],z0=50)
-        z = open.z
-        y = short.y
-        a = react.y
+        networks = [
+            rf.N(f=[1], s=[1], z0=[50]),
+            rf.N(f=[1], s=[-1], z0=[50]),
+            rf.N(f=[1], s=[[0, 1], [1, 0]], z0=[50]),
+            rf.N(f=[1], s=[[1, 0], [0, 1]], z0=50),
+            rf.N(f=[1], s=[[-1, 0], [0, -1]], z0=50),
+            rf.N(f=[1], s=[[0.5, 0.5], [0.5, 0.5]], z0=[50]),
+            rf.N(f=[1], s=[[-0.5, -0.5], [-0.5, -0.5]], z0=[50]),
+        ]
+        # These conversion can be very inaccurate since results are very close
+        # to singular.
+        # Test that they are close with loose accuracy tolerance.
+        for net in networks:
+            for s_def in rf.S_DEFINITIONS:
+                npy.testing.assert_allclose(rf.z2s(rf.s2z(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3)
+                npy.testing.assert_allclose(rf.y2s(rf.s2y(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3)
 
     def test_conversions(self):
         #Converting to other format and back to S-parameters should return the original network
@@ -390,19 +630,54 @@ class NetworkTestCase(unittest.TestCase):
         #Converting to other format and back to S-parameters should return the original network
         for ports in range(3, 6):
             s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
-            ntwk_random = rf.Network(s=s_random, frequency=self.freq)
-            for test_z0 in (50, 20+60j, 90-50j):
-                for test_ntwk in (self.ntwk1, self.ntwk2, self.ntwk3, ntwk_random):
-                    ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=test_z0)
-                    npy.testing.assert_allclose(rf.z2s(rf.s2z(ntwk.s, test_z0), test_z0), ntwk.s)
-                    npy.testing.assert_allclose(rf.y2s(rf.s2y(ntwk.s, test_z0), test_z0), ntwk.s)
+            test_ntwk = rf.Network(s=s_random, frequency=self.freq)
+            random_z0 = npy.random.uniform(1, 100, (self.freq.npoints, ports)) +\
+            1j * npy.random.uniform(-100, 100, (self.freq.npoints, ports))
+            for test_z0 in (50, random_z0):
+                for s_def in rf.S_DEFINITIONS:
+                    ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=test_z0, s_def=s_def)
+                    npy.testing.assert_allclose(rf.z2s(rf.s2z(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s)
+                    npy.testing.assert_allclose(rf.y2s(rf.s2y(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s)
+
+    def test_y_z_compatability(self):
+        # Test that npy.linalg.inv(Z) == Y
+        fpoints = 3
+        for p in range(2, 6):
+            s = npy.random.uniform(-1, 1, (fpoints, p, p)) + 1j * npy.random.uniform(-1, 1, (fpoints, p, p))
+            random_z0 = npy.random.uniform(1, 100, (fpoints, p)) + 1j * npy.random.uniform(-100, 100, (fpoints, p))
+            for test_z0 in (50, random_z0):
+                for s_def in rf.S_DEFINITIONS:
+                    z = rf.s2z(s, test_z0, s_def=s_def)
+                    y = npy.linalg.inv(z)
+                    npy.testing.assert_allclose(rf.y2s(y, test_z0, s_def=s_def), s)
+
+    def test_unknown_s_def(self):
+        # Test that Exception is raised when given unknown s_def
+        s = npy.array([0]).reshape(1, 1, 1)
+        z0 = npy.array([50])
+        # These should work
+        # These also test that functions work with dtype=float input
+        rf.s2z(s, z0)
+        rf.z2s(s, z0)
+        rf.s2y(s, z0)
+        rf.y2s(s, z0)
+        with pytest.raises(Exception) as e:
+            rf.s2z(s, z0, s_def='error')
+        with pytest.raises(Exception) as e:
+            rf.z2s(s, z0, s_def='error')
+        with pytest.raises(Exception) as e:
+            rf.y2s(s, z0, s_def='error')
+        with pytest.raises(Exception) as e:
+            rf.s2y(s, z0, s_def='error')
 
     def test_sparam_renormalize(self):
         #Converting to other format and back to S-parameters should return the original network
         for ports in range(2, 6):
             s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
             test_ntwk = rf.Network(s=s_random, frequency=self.freq)
-            for test_z0 in (50, 20+60j, 70-30j):
+            random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
+                        1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
+            for test_z0 in (50, 20+60j, random_z0):
                 for method in rf.S_DEFINITIONS:
                     ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=50)
                     ntwk_renorm = ntwk.copy()
@@ -410,6 +685,48 @@ class NetworkTestCase(unittest.TestCase):
                     ntwk_renorm.renormalize(50, method)
                     npy.testing.assert_allclose(ntwk_renorm.s, ntwk.s)
 
+    def test_sparam_renorm_s2s(self):
+        """
+        Test changing S-parameter definition with complex ports
+        """
+        for ports in range(2, 6):
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            test_ntwk = rf.Network(s=s_random, frequency=self.freq)
+            random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
+                        1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
+            for def1 in rf.S_DEFINITIONS:
+                for def2 in rf.S_DEFINITIONS:
+                    ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=random_z0, s_def=def1)
+                    ntwk_renorm = ntwk.copy()
+                    ntwk_renorm.renormalize(ntwk.z0, s_def=def2)
+                    npy.testing.assert_allclose(ntwk_renorm.z, ntwk.z)
+                    ntwk_renorm.renormalize(ntwk.z0, s_def=def1)
+                    npy.testing.assert_allclose(ntwk_renorm.s, ntwk.s)
+                    npy.testing.assert_allclose(ntwk_renorm.z0, ntwk.z0)
+
+    def test_sparam_renorm_different_z0(self):
+        """
+        Test changing S-parameter definition with complex ports.
+        renormalize handles cases with same z0 and different z0 before and
+        after conversion with different method.
+        """
+        for ports in range(2, 6):
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            test_ntwk = rf.Network(s=s_random, frequency=self.freq)
+            random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
+                        1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
+            random_z0_2 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
+                        1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
+            for def1 in rf.S_DEFINITIONS:
+                for def2 in rf.S_DEFINITIONS:
+                    ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=random_z0, s_def=def1)
+                    ntwk_renorm = ntwk.copy()
+                    ntwk_renorm.renormalize(random_z0_2, s_def=def2)
+                    npy.testing.assert_allclose(ntwk_renorm.z, ntwk.z)
+                    ntwk_renorm.renormalize(ntwk.z0, s_def=def1)
+                    npy.testing.assert_allclose(ntwk_renorm.s, ntwk.s)
+                    npy.testing.assert_allclose(ntwk_renorm.z0, ntwk.z0)
+
     def test_setters(self):
         s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
         ntwk = rf.Network(s=s_random, frequency=self.freq)
@@ -427,6 +744,27 @@ class NetworkTestCase(unittest.TestCase):
         ntwk.h = ntwk.h
         npy.testing.assert_allclose(ntwk.s, s_random)
 
+    def test_s_def_setters(self):
+        s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
+        ntwk = rf.Network(s=s_random, frequency=self.freq)
+        ntwk.z0 = npy.random.uniform(1, 100, len(ntwk.z0)) + 1j*npy.random.uniform(-100, 100, len(ntwk.z0))
+        ntwk.s = ntwk.s
+
+        s_traveling = rf.s2s(s_random, ntwk.z0, 'traveling', ntwk.s_def)
+        s_power = rf.s2s(s_random, ntwk.z0, 'power', ntwk.s_def)
+        s_pseudo = rf.s2s(s_random, ntwk.z0, 'pseudo', ntwk.s_def)
+
+        ntwk.s_traveling = s_traveling
+        npy.testing.assert_allclose(ntwk.s, s_random)
+        ntwk.s_power = s_power
+        npy.testing.assert_allclose(ntwk.s, s_random)
+        ntwk.s_pseudo = s_pseudo
+        npy.testing.assert_allclose(ntwk.s, s_random)
+
+        npy.testing.assert_allclose(ntwk.s_traveling, s_traveling)
+        npy.testing.assert_allclose(ntwk.s_power, s_power)
+        npy.testing.assert_allclose(ntwk.s_pseudo, s_pseudo)
+
     def test_sparam_conversion_with_complex_char_impedance(self):
         """
         Renormalize a 2-port network wrt to complex characteristic impedances
@@ -570,7 +908,7 @@ class NetworkTestCase(unittest.TestCase):
         ntwk.z0 = z0
         self.assertTrue(npy.allclose(ntwk.z0, npy.array([z0, z0, z0], dtype=complex)))
 
-        # If the s-array has been set and we want to set z0 along the frequency axis, 
+        # If the s-array has been set and we want to set z0 along the frequency axis,
         # wer require the frequency vector to be set too.
         # Unfortunately the frequency vector and the s shape can distinguish
         z0 = [1,2,3]
@@ -590,13 +928,27 @@ class NetworkTestCase(unittest.TestCase):
         ntwk.z0 = npy.array(z0) + 1 # Passing as npy.array
         self.assertTrue(npy.allclose(ntwk.z0, npy.array(z0, dtype=complex)+1))
 
-        # Setting the frequency is required to be set, as the matrix size is checked against the 
+        # Setting the frequency is required to be set, as the matrix size is checked against the
         # frequency vector
         ntwk.s = npy.random.rand(1,2,2)
         ntwk.f = [1]
         ntwk.z0 = z0
         self.assertTrue(npy.allclose(ntwk.z0, npy.array(z0, dtype=complex)))
 
+    def test_z0_assign(self):
+        """ Test that z0 getter returns a reference to _z0 so that it can
+        be assigned to with array indexing"""
+        ntwk = rf.Network(s=npy.zeros((3,2,2)), f=[1,2,3])
+        ntwk.z0[0, 0] = 2
+        self.assertTrue(ntwk.z0[0, 0] == 2)
+
+        ntwk = rf.Network(s=npy.zeros((3,2,2)), f=[1,2,3], z0=npy.ones(3))
+        ntwk.z0[0, 0] = 2
+        self.assertTrue(ntwk.z0[0, 0] == 2)
+
+        ntwk = rf.Network(s=npy.zeros((3,2,2)), f=[1,2,3], z0=npy.ones((3,2)))
+        ntwk.z0[0, 0] = 2
+        self.assertTrue(ntwk.z0[0, 0] == 2)
 
     def test_yz(self):
         tinyfloat = 1e-12
@@ -646,6 +998,7 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue( ((a+2+2j).s == npy.array([[[3+4j]],[[5+6j]]])).all())
         # operating on list
         self.assertTrue( ((a+[1+1j,2+2j]).s == npy.array([[[2+3j]],[[5+6j]]])).all())
+     
 
     def test_interpolate(self):
         a = rf.N(f=[1,2],s=[1+2j, 3+4j],z0=1)
@@ -680,14 +1033,14 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue(b.z0[1] == 0.5*(a.z0[0] + a.z0[1]))
         self.assertTrue(b.z0[-1] == a.z0[-1])
 
-    def test_interpolate_self_npoints(self):
-        a = rf.N(f=[1,2],s=[1+2j, 3+4j],z0=1)
-        a.interpolate_self_npoints(4)
-        # TODO: numerically test for correct interpolation
-
-    def test_interpolate_from_f(self):
-        a = rf.N(f=[1,2],s=[1+2j, 3+4j],z0=1)
-        a.interpolate_from_f(npy.linspace(1,2,4), unit='ghz')
+    def test_interpolate_self(self):
+        """Test resample."""
+        a = rf.N(f=[1,2], s=[1+2j, 3+4j], z0=1)
+        a.interpolate_self(4)
+        self.assertEqual(len(a), 4)
+        # also test the alias name
+        a.resample(6)
+        self.assertEqual(len(a), 6)
         # TODO: numerically test for correct interpolation
 
     def test_slicer(self):
@@ -1129,6 +1482,21 @@ class NetworkTestCase(unittest.TestCase):
         tee2 = rf.n_twoports_2_nport(ntw_list, nports=3)
         self.assertTrue(tee2 == tee)
 
+    def test_subnetwork_port_names(self):
+        """ Test that subnetwork keeps port_names property. Issue #429 """
+        self.ntwk1.port_names = ['A', 'B']
+        extract_ports = ['A']  # list of port names to extract
+        extract_ports_idx = [self.ntwk1.port_names.index(p) for p in extract_ports]  # get port indices
+        sub_nwk1 = self.ntwk1.subnetwork(extract_ports_idx)
+        self.assertEqual(sub_nwk1.port_names, extract_ports)
+
+        tee = rf.data.tee
+        tee.port_names = ['A', 'B', 'C']
+        extract_ports = ['A', 'C']
+        extract_ports_idx = [tee.port_names.index(p) for p in extract_ports]
+        sub_nwk = tee.subnetwork(extract_ports_idx)
+        self.assertEqual(sub_nwk.port_names, extract_ports)
+
     def test_invalid_freq(self):
 
         dat = npy.arange(5)
