@@ -1,9 +1,8 @@
 import warnings
-from collections import OrderedDict, Iterable
-
 import numpy as np
 import skrf
-import pyvisa
+from collections import OrderedDict
+from collections.abc import Iterable
 
 from . import abcvna
 from . import keysight_fieldfox_scpi
